changeset 292:bfcea6e2ab3f div-fixes-6

translate: nullzeit -> ndl The code shall be in English :-) Signed-off-by: Jan Mulder <jlmulder@xs4all.nl>
author Jan Mulder <jlmulder@xs4all.nl>
date Thu, 02 May 2019 09:24:54 +0200
parents 24ff72e627f4
children 02d10d955be2
files Discovery/Inc/vpm.h Discovery/Src/vpm.c
diffstat 2 files changed, 14 insertions(+), 14 deletions(-) [+]
line wrap: on
line diff
--- a/Discovery/Inc/vpm.h	Thu May 02 09:16:07 2019 +0200
+++ b/Discovery/Inc/vpm.h	Thu May 02 09:24:54 2019 +0200
@@ -32,7 +32,7 @@
 
 extern long vpm_time_calc_begin;
 enum DECOLIST{DECOSTOPS,FUTURESTOPS,BAILOUTSTOPS, OFF = -1}; // order is important!!
-enum VPM_CALC_STATUS{CALC_END, CALC_BEGIN, CALC_CRITICAL, CALC_FINAL_DECO, CALC_NULLZEIT };
+enum VPM_CALC_STATUS{CALC_END, CALC_BEGIN, CALC_CRITICAL, CALC_FINAL_DECO, CALC_NDL };
 
 float schreiner_equation__2(float *initial_inspired_gas_pressure,float *rate_change_insp_gas_pressure,float *interval_time_minutes,  const float *gas_time_constant,float *initial_gas_pressure);
 
--- a/Discovery/Src/vpm.c	Thu May 02 09:16:07 2019 +0200
+++ b/Discovery/Src/vpm.c	Thu May 02 09:24:54 2019 +0200
@@ -187,7 +187,7 @@
 static int vpm_check_converged(_Bool calc_nulltime);
 static int vpm_calc_final_deco(_Bool begin);
 static void BOYLES_LAW_COMPENSATION (float* First_Stop_Depth,float * Deco_Stop_Depth,float* Step_Size);
-static int vpm_calc_nullzeit(void);
+static int vpm_calc_ndl(void);
 static void  vpm_init_1(void);
 static void vpm_calc_deco_ceiling(void);
 
@@ -242,7 +242,7 @@
 
     if(pINPUT->dive_time_seconds < 10)
     {
-        vpm_calc_status = CALC_NULLZEIT;
+        vpm_calc_status = CALC_NDL;
         return vpm_calc_status;
     }
     pVpm = pVPM;
@@ -250,16 +250,16 @@
     pDecoInfo = pDECOINFO;
     pDiveSettings = pSettings;
 
-    if(vpm_calc_status == CALC_NULLZEIT)
+    if(vpm_calc_status == CALC_NDL)
     {
-        tmp_calc_status = vpm_calc_nullzeit();
+        tmp_calc_status = vpm_calc_ndl();
     }
     else
     {
         tmp_calc_status = CALC_BEGIN;
     }
     //Normal Deco calculation
-    if(tmp_calc_status != CALC_NULLZEIT)
+    if(tmp_calc_status != CALC_NDL)
     {
         max_first_stop_depth =  pVpm->max_first_stop_depth_save;
         run_time_start_of_deco_zone = pVpm->run_time_start_of_deco_zone_save;
@@ -694,7 +694,7 @@
                 pDecoInfo->output_ndl_seconds = 0;
             }
 
-            return CALC_NULLZEIT;
+            return CALC_NDL;
                     /* exit the critical volume l */
         }
 
@@ -2275,12 +2275,12 @@
 }
 
 /* =============================================================================== */
 //	vpm_calc_nullzeit
 //     Purpose: This function calcs zero time (time where no decostops are needed)
 //===============================================================================
 #define MAX_NDL	240
 
-static int vpm_calc_nullzeit(void)
+static int vpm_calc_ndl(void)
 {
     static float future_helium_pressure[16];
     static float future_nitrogen_pressure[16];
@@ -2319,7 +2319,7 @@
                 if(temp_segment_time >= MAX_NDL)
                 {
                     pDecoInfo->output_ndl_seconds = temp_segment_time * 60;
-                    return CALC_NULLZEIT;
+                    return CALC_NDL;
                 }
                 run_time += 60;
                 //goto L700;
@@ -2354,12 +2354,12 @@
             if(temp_segment_time >= MAX_NDL)
             {
                 pDecoInfo->output_ndl_seconds = temp_segment_time * 60;
-                return CALC_NULLZEIT;
+                return CALC_NDL;
             }
             if(nullzeit_unter60 && temp_segment_time > 60)
             {
                 nullzeit_unter60 = false;
-                return CALC_NULLZEIT;
+                return CALC_NDL;
             }
             run_time += 5;
             //goto L700;
@@ -2405,7 +2405,7 @@
         temp_segment_time += 5;
     pDecoInfo->output_ndl_seconds = temp_segment_time * 60;
     if(temp_segment_time > 1)
-        return CALC_NULLZEIT;
+        return CALC_NDL;
     else
         return CALC_BEGIN;
 }
@@ -2275,12 +2275,12 @@
 
 /* =============================================================================== */
-//	vpm_calc_nullzeit
-//     Purpose: This function calcs zero time (time where no decostops are needed)
+//	vpm_calc_ndl
+//     Purpose: This function computes NDL (time where no decostops are needed)
 //===============================================================================
 #define MAX_NDL	240